@@ -9,8 +9,8 @@
 #include "containermodel.h"
 
 /**
-  * Model for the tree of lessons.
-  */
+ * Model for the tree of lessons.
+ */
 class LessonModel : public ContainerModel
 {
     Q_OBJECT
@@ -18,28 +18,28 @@ class LessonModel : public ContainerModel
 public:
     /** When splitting a lesson into smaller ones - how to sort the entries into lessons.*/
     enum SplitLessonOrder {
-        Sorted,    /**< The order of the entries in the document */
+        Sorted, /**< The order of the entries in the document */
         Random /**< Randomized */
     };
 
     explicit LessonModel(QObject *parent = 0);
 
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
-    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 
     /**
      * Divide a lesson into smaller ones.
-     * Tip: If you create a lesson that is >= the original one and use random order, you get your lesson reshuffled. Maybe that is sometimes useful. For now the lessons are appended at the end.
+     * Tip: If you create a lesson that is >= the original one and use random order, you get your lesson reshuffled. Maybe that is sometimes useful. For now the
+     * lessons are appended at the end.
      * @param containerIndex lesson to split
      * @param entriesPerLesson number of entries in each new lesson
      * @param order one of SplitLessonOrder
-        */
-    void splitLesson(const QModelIndex& containerIndex, int entriesPerLesson, SplitLessonOrder order);
+     */
+    void splitLesson(const QModelIndex &containerIndex, int entriesPerLesson, SplitLessonOrder order);
 
 protected:
-    KEduVocContainer * rootContainer() const Q_DECL_OVERRIDE;
+    KEduVocContainer *rootContainer() const override;
 };
 
-
 #endif
